@@ -244,8 +244,8 @@ ma_d_bb <- ma_d_barebones <- function(d, n1, n2 = rep(NA, length(d)), n_adj = NU
           escalc_obj$weight <- wt_vec
           escalc_obj$residual <- d - mean_d
 
-          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj) %>% mutate(citekey = as.character(citekey))
-          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj) %>% mutate(sample_id = as.character(sample_id))
+          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj)
+          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj)
           if(any(colnames(data) == "original_order")) escalc_obj <- cbind(original_order = data$original_order, escalc_obj)
           class(escalc_obj) <- c("escalc", "data.frame")
      }
