@@ -776,6 +776,10 @@ plot_forest <- function(ma_obj, analyses = "all", match = c("all", "any"), case_
                sd_es <- "sd_r_c"
                if(is.null(x_lab)) x_lab <- expression(Corrected~~Correlation~~(italic(r)))
           }
+     }else if(ma_metric == "generic"){
+       mean_es <- "mean_es"
+       sd_es <- "sd_es"
+       if(is.null(x_lab)) x_lab <- expression(Effect~~Size)
      }else{
           if(ma_method == "barebones"){
                mean_es <- "mean_d"
@@ -788,7 +792,6 @@ plot_forest <- function(ma_obj, analyses = "all", match = c("all", "any"), case_
           }
      }
 
-
      mat <- as.data.frame(mat, stringsAsFactors = FALSE)
      if (isFALSE(recompute_ci)) {
        conf_out <- mat[, paste("CI", c("LL", "UL"), conf_level * 100, sep = "_")]
